function [res_struct] = ConfigCost()
% Configure cost functions for the simulation example (Sec. 4).
%
% --
% Self-tuning LQR, Trimpe et al. IFAC World Congress 2014 paper
%
% Copyright:
% Sebastian Trimpe
% Max-Planck-Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%
% Revision history
% [13.11.13]   first version to be published

% Rerefence cost
res_struct.Q_ref = diag([100, 100]);
res_struct.R_ref = 1;


% Design cost, parametrized through theta.
res_struct.Q = @(theta) diag([100*theta(1), 100*theta(2)]);
res_struct.R = @(theta) 1;


% Constraint projection
res_struct.constrProjFcn = @constrProj;
return;


% %% AUXILIARY FUNCTIONS
% %% Constraint projection function
% Project theta such that theta_i>=0.
% Simply set any negative number to 1e-4.
function theta_proj = constrProj(theta)
smallNumber = 1e-4;
theta_proj = theta;

if theta_proj(1)<0
    theta_proj(1) = smallNumber;
end;

if theta_proj(2)<0
    theta_proj(2) = smallNumber;
end;

return;